pub struct Insn(pub u64);Expand description
Identifies an NNIL value by its stable position in the instruction list.
The tuple field is public so a backend can use the number directly. The wrapper prevents a value handle from being used by mistake as a guest address or label.
Tuple Fields
0: u64Trait Implementations
impl Copy for Insn
impl Eq for Insn
Sourceimpl Ord for Insn
impl Ord for Insn
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Insn
impl PartialOrd for Insn
impl StructuralPartialEq for Insn